pub struct AsyncStorageLoop<B: Backend, IO: Io, S> { /* private fields */ }Expand description
Background loop task state.
The background loop task is not allowed to exit, unless it was notified for shutdown.
On shutdown, attempts to empty the queue, and flush the receiver. When the last handle of the receiver is dropped, and the queue is empty, exit.
Implementations
Sourceimpl<B, FS, S> AsyncStorageLoop<B, FS, S>
impl<B, FS, S> AsyncStorageLoop<B, FS, S>
Sourcepub async fn run(self)
pub async fn run(self)
Schedules durability jobs. This loop is not allowed to fail, or lose jobs.
A job is prepared by calling Scheduler::prepare(..). The job is spawned, and it returns a
JobResult, which is then returned to the scheduler by calling Scheduler::report(..).
When a request is received, it is immediately scheduled by calling Scheduler::register
with it.
The loop is only allowed to shutdown if the receiver is closed, and the scheduler is empty,
or if force_shutdown is called, in which case everything is dropped in place.